@@ -226,7 +226,7 @@ test_expect_success 'Edit patch diff which fails to apply' '
 
 test_expect_success 'Edit patch name of top patch' '
     write_script diffedit <<-\EOF &&
-	sed "s/^Patch: \\+p2/Patch: p2-new/" "$1" >"$1".tmp && mv "$1".tmp "$1"
+	sed "s/^Patch:  *p2/Patch: p2-new/" "$1" >"$1".tmp && mv "$1".tmp "$1"
 	EOF
     test_when_finished "rm -f diffedit" &&
     EDITOR=./diffedit stg edit -d &&
@@ -237,7 +237,7 @@ test_expect_success 'Edit patch name of top patch' '
 
 test_expect_success 'Edit patch name of non-top applied patch' '
     write_script diffedit <<-\EOF &&
-	sed "s/^Patch: \\+p1/Patch: p1-new/" "$1" >"$1".tmp && mv "$1".tmp "$1"
+	sed "s/^Patch:  *p1/Patch: p1-new/" "$1" >"$1".tmp && mv "$1".tmp "$1"
 	EOF
     test_when_finished "rm -f diffedit" &&
     EDITOR=./diffedit stg edit -d p1 &&
@@ -248,7 +248,7 @@ test_expect_success 'Edit patch name of non-top applied patch' '
 
 test_expect_success 'Edit patch name of non-applied patch' '
     write_script diffedit <<-\EOF &&
-	sed "s/^Patch: \\+p3/Patch: p3-new/" "$1" >"$1".tmp && mv "$1".tmp "$1"
+	sed "s/^Patch:  *p3/Patch: p3-new/" "$1" >"$1".tmp && mv "$1".tmp "$1"
 	EOF
     test_when_finished "rm -f diffedit" &&
     EDITOR=./diffedit stg edit -d p3 &&
@@ -259,7 +259,7 @@ test_expect_success 'Edit patch name of non-applied patch' '
 
 test_expect_success 'Edit patch name of hidden patch' '
     write_script diffedit <<-\EOF &&
-	sed "s/^Patch: \\+p4/Patch: p4-new/" "$1" >"$1".tmp && mv "$1".tmp "$1"
+	sed "s/^Patch:  *p4/Patch: p4-new/" "$1" >"$1".tmp && mv "$1".tmp "$1"
 	EOF
     test_when_finished "rm -f diffedit" &&
     EDITOR=./diffedit stg edit -d p4 &&
@@ -269,7 +269,7 @@ test_expect_success 'Edit patch name of hidden patch' '
 
 test_expect_success 'Clearing the patch name results in a new autogenerated name' '
     write_script diffedit <<-\EOF &&
-	sed "s/^Patch: \\+p2/Patch:/" "$1" >"$1".tmp && mv "$1".tmp "$1"
+	sed "s/^Patch:  *p2/Patch:/" "$1" >"$1".tmp && mv "$1".tmp "$1"
 	EOF
     test_when_finished "rm -f diffedit" &&
     EDITOR=./diffedit stg edit -d &&
@@ -280,7 +280,7 @@ test_expect_success 'Clearing the patch name results in a new autogenerated name
 
 test_expect_success 'Rename patch and edit its diff' '
     write_script diffedit <<-\EOF &&
-	sed -e "s/^Patch: \\+p2/Patch: p2-new/" -e "s/twoliner/twoliner-new/" "$1" >"$1".tmp && mv "$1".tmp "$1"
+	sed -e "s/^Patch:  *p2/Patch: p2-new/" -e "s/twoliner/twoliner-new/" "$1" >"$1".tmp && mv "$1".tmp "$1"
 	EOF
     test_when_finished "rm -f diffedit" &&
     EDITOR=./diffedit stg edit -d &&
